.. DipolEq documentation master file, created by
   sphinx-quickstart on Fri May 31 15:51:17 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.md
   :parser: myst_parser.sphinx_


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :titlesonly:

   dipoleq
   core


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
